==> zio-aws-ec2_2.12-5.20.17.2-sources.jar: zio/aws/ec2/model/DescribeTransitGatewayConnectsRequest.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{
  TransitGatewayMaxResults,
  TransitGatewayAttachmentId
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeTransitGatewayConnectsRequest(
    transitGatewayAttachmentIds: Optional[
      Iterable[TransitGatewayAttachmentId]
    ] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    maxResults: Optional[TransitGatewayMaxResults] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayConnectsRequest = {
    import DescribeTransitGatewayConnectsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayConnectsRequest
      .builder()
      .optionallyWith(
        transitGatewayAttachmentIds.map(value =>
          value.map { item =>
            TransitGatewayAttachmentId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.transitGatewayAttachmentIds)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value => TransitGatewayMaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeTransitGatewayConnectsRequest.ReadOnly =
    zio.aws.ec2.model.DescribeTransitGatewayConnectsRequest
      .wrap(buildAwsValue())
}
object DescribeTransitGatewayConnectsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayConnectsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeTransitGatewayConnectsRequest =
      zio.aws.ec2.model.DescribeTransitGatewayConnectsRequest(
        transitGatewayAttachmentIds.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def transitGatewayAttachmentIds: Optional[List[TransitGatewayAttachmentId]]
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Optional[TransitGatewayMaxResults]
    def nextToken: Optional[String]
    def getTransitGatewayAttachmentIds
        : ZIO[Any, AwsError, List[TransitGatewayAttachmentId]] =
      AwsError.unwrapOptionField(
        "transitGatewayAttachmentIds",
        transitGatewayAttachmentIds
      )
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, TransitGatewayMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayConnectsRequest
  ) extends zio.aws.ec2.model.DescribeTransitGatewayConnectsRequest.ReadOnly {
    override val transitGatewayAttachmentIds
        : Optional[List[TransitGatewayAttachmentId]] = zio.aws.core.internal
      .optionalFromNullable(impl.transitGatewayAttachmentIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.primitives.TransitGatewayAttachmentId(item)
        }.toList
      )
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Optional[TransitGatewayMaxResults] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.ec2.model.primitives.TransitGatewayMaxResults(value)
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayConnectsRequest
  ): zio.aws.ec2.model.DescribeTransitGatewayConnectsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.158.4-sources.jar: zio/aws/ec2/model/DescribeTransitGatewayConnectsRequest.scala <==
package zio.aws.ec2.model
import java.lang.Integer
import zio.aws.ec2.model.primitives.{
  TransitGatewayMaxResults,
  TransitGatewayAttachmentId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeTransitGatewayConnectsRequest(
    transitGatewayAttachmentIds: Option[Iterable[TransitGatewayAttachmentId]] =
      None,
    filters: Option[Iterable[zio.aws.ec2.model.Filter]] = None,
    maxResults: Option[TransitGatewayMaxResults] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayConnectsRequest = {
    import DescribeTransitGatewayConnectsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayConnectsRequest
      .builder()
      .optionallyWith(
        transitGatewayAttachmentIds.map(value =>
          value.map { item =>
            TransitGatewayAttachmentId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.transitGatewayAttachmentIds)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value => TransitGatewayMaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeTransitGatewayConnectsRequest.ReadOnly =
    zio.aws.ec2.model.DescribeTransitGatewayConnectsRequest
      .wrap(buildAwsValue())
}
object DescribeTransitGatewayConnectsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayConnectsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeTransitGatewayConnectsRequest =
      zio.aws.ec2.model.DescribeTransitGatewayConnectsRequest(
        transitGatewayAttachmentIds.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def transitGatewayAttachmentIds: Option[List[TransitGatewayAttachmentId]]
    def filters: Option[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Option[TransitGatewayMaxResults]
    def nextToken: Option[String]
    def getTransitGatewayAttachmentIds
        : ZIO[Any, AwsError, List[TransitGatewayAttachmentId]] =
      AwsError.unwrapOptionField(
        "transitGatewayAttachmentIds",
        transitGatewayAttachmentIds
      )
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, TransitGatewayMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayConnectsRequest
  ) extends zio.aws.ec2.model.DescribeTransitGatewayConnectsRequest.ReadOnly {
    override val transitGatewayAttachmentIds
        : Option[List[TransitGatewayAttachmentId]] = scala
      .Option(impl.transitGatewayAttachmentIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.primitives.TransitGatewayAttachmentId(item)
        }.toList
      )
    override val filters: Option[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      scala
        .Option(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Option[TransitGatewayMaxResults] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.ec2.model.primitives.TransitGatewayMaxResults(value)
      )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayConnectsRequest
  ): zio.aws.ec2.model.DescribeTransitGatewayConnectsRequest.ReadOnly =
    new Wrapper(impl)
}
